<?php
/**
 * @author FiloBlu
 * @copyright Copyright (c) 2019 FiloBlu (https://filoblu.com)
 */
namespace FiloBlu\ExtAmastyXnotif\Block\Adminhtml\Stock\Renderer;

use Magento\Eav\Model\Entity\AttributeFactory;
use \Magento\Framework\DataObject;
use Magento\Eav\Model\Entity\Attribute\Source\BooleanFactory;


class ProductAttribute extends \Magento\Backend\Block\Widget\Grid\Column\Renderer\Text
{
    /**
     * @var AttributeFactory
     */
    protected $attributeFactory;

    /**
     * @var BooleanFactory
     */
    protected $booleanFactory;

    /**
     * ProductAttribute constructor.
     * @param \Magento\Backend\Block\Context $context
     * @param \Magento\Store\Model\WebsiteFactory $websiteFactory
     * @param AttributeFactory $attributeFactory
     * @param BooleanFactory $booleanFactory
     * @param array $data
     */
    public function __construct(
        \Magento\Backend\Block\Context $context,
        \Magento\Store\Model\WebsiteFactory $websiteFactory,
        AttributeFactory $attributeFactory,
        BooleanFactory $booleanFactory,

        array $data = []
    ) {
        parent::__construct($context, $data);
        $this->attributeFactory = $attributeFactory;
        $this->booleanFactory = $booleanFactory;
    }

    /**
     * @param DataObject $row
     * @return mixed|string
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function render(DataObject $row)
    {
        $attribute = $this->attributeFactory->create()->loadByCode('catalog_product', $this->getColumn()->getId());

        $isBoolean = $attribute->getFrontend()->getConfigField('input') == 'boolean';
        $value = $row->getData($this->getColumn()->getIndex());
        if ($isBoolean){
            $options = $this->booleanFactory->create()->getAllOptions();
            foreach ($options as $name=>$label){
                if($name == $value)
                    return $label;
            }
            return $value;
        }
        if ( $attribute->usesSource()) {
            $options= $attribute->getSource()->getAllOptions();
            foreach ($options as $option){
                if($option['value'] == $value)
                    return $option['label'];
            }
            return $value;
        }
        return $value;


    }
}
